@@ -19,7 +19,16 @@ version <- function(pkg="TAM"){
 .onAttach <- function(libname,pkgname){
   d <- packageDescription("TAM")
   packageStartupMessage("::...........................::\n",
-		paste(":: " , d$Package," " , d$Version," (",d$Date,")  ::",sep="") ,
+		paste(":: " , d$Package," " , d$Version," (",d$Date,")   ::",sep="") ,
 		paste("\n:: Test Analysis Modules     ::") ,
 		"\n::...........................::\n" )
-}
\ No newline at end of file
+}
+
+#*************************************************
+# R session info
+Rsessinfo <- function(){
+    si <- Sys.info()
+    si2 <- sessionInfo()
+    paste0( si2$R.version$version.string , " " , si2$R.version$system 
+             , " | nodename = " , si["nodename"] , " | login = " , si["login"] )
+            }
\ No newline at end of file
